@@ -35,7 +35,9 @@ pub extern crate hex;
 
 #[allow(unused_imports)]
 #[macro_use]
+/// Re-export of the `async_trait` macro crate.
 pub extern crate async_trait;
+/// Mark an Ockam Worker implementation.
 pub use async_trait::async_trait as worker;
 
 extern crate ockam_macros;
@@ -49,6 +51,7 @@ mod error;
 mod message;
 mod processor;
 mod routing;
+pub mod traits;
 mod uint;
 pub mod vault;
 mod worker;
@@ -62,38 +65,9 @@ pub use traits::*;
 pub use uint::*;
 pub use worker::*;
 
-#[cfg(feature = "std")]
-pub use std::println;
 #[cfg(all(not(feature = "std"), feature = "alloc"))]
-/// println macro for no_std
-pub mod println_no_std {
-    #[macro_export]
-    /// implements println for no_std by wrapping the tracing::info! macro
-    macro_rules! println {
-        ($($arg:tt)*) => {{
-            tracing::info!($($arg)*);
-        }};
-    }
-}
-
-/// Module for custom implementation of standard traits.
-pub mod traits {
-    use crate::compat::boxed::Box;
-    use crate::error::Result;
-
-    /// Clone trait for async structs.
-    #[async_trait]
-    pub trait AsyncTryClone: Sized {
-        /// Try cloning a object and return an `Err` in case of failure.
-        async fn async_try_clone(&self) -> Result<Self>;
-    }
-    #[async_trait]
-    impl<D> AsyncTryClone for D
-    where
-        D: Clone + Sync,
-    {
-        async fn async_try_clone(&self) -> Result<Self> {
-            Ok(self.clone())
-        }
-    }
-}
+#[doc(hidden)]
+pub use compat::println;
+#[cfg(feature = "std")]
+#[doc(hidden)]
+pub use std::println;
