@@ -9,7 +9,7 @@ use core::ops::Deref;
 use core::str::from_utf8;
 use serde::{Deserialize, Serialize};
 
-/// A collection of Addresses
+/// A read-only set containing a `Vec` of [`Address`] structures.
 #[derive(Debug, Clone, Hash, Ord, PartialOrd, Eq, PartialEq, Serialize, Deserialize)]
 pub struct AddressSet(Vec<Address>);
 
@@ -24,7 +24,7 @@ impl AddressSet {
         self.0.first().cloned().unwrap()
     }
 
-    /// Check if an address is contained in this set
+    /// Check if an address is contained in this set.
     pub fn contains(&self, a2: &Address) -> bool {
         self.0
             .iter()
@@ -85,7 +85,7 @@ impl<'a> From<&'a str> for AddressSet {
     }
 }
 
-/// A generic component address
+/// A generic address type.
 ///
 /// The address type is parsed by routers to determine the next local
 /// hop in the router chain to resolve a route to a remote connection.
@@ -93,41 +93,51 @@ impl<'a> From<&'a str> for AddressSet {
 /// ## Parsing addresses
 ///
 /// While addresses are concrete types, creating them from strings is
-/// possible for ergonomics reasons.  When parsing an address from a
-/// string, the first `#` symbol is used to separate the type from the
-/// rest of the address.  If no `#` symbol is found, the address is
-/// assumed to be of `tt = 0` (local worker).
+/// possible for ergonomic reasons.
+///
+/// When parsing an address from a string, the first `#` symbol is
+/// used to separate the transport type from the rest of the address.
+/// If no `#` symbol is found, the address is assumed to be of `transport =
+/// 0`, the Local Worker transport type.
+///
+/// For example:
+/// * `"0#alice"` represents a local worker with the address: `alice`.
+/// * `"1#carol"` represents a remote worker with the address `carol`, reachable over TCP transport.
+///
 #[derive(Serialize, Deserialize, Clone, Hash, Ord, PartialOrd, Eq, PartialEq)]
 pub struct Address {
-    /// The address type
+    /// The transport type
     pub tt: u8,
     inner: Vec<u8>,
 }
-/// An error which is returned when address parsing from string fails
+
+/// An error which is returned when address parsing from string fails.
 #[derive(Debug)]
 pub struct AddressParseError {
     kind: AddressParseErrorKind,
 }
-/// Enum to store the cause of address parsing failure
+
+/// Enum to store the cause of an address parsing failure.
 #[derive(Debug, Clone, PartialEq, Eq)]
 #[non_exhaustive]
 pub enum AddressParseErrorKind {
-    /// Unable to parse address num in the address string
+    /// Unable to parse address num in the address string.
     InvalidType(core::num::ParseIntError),
-    /// Address string has more than one '#' separator
+    /// Address string has more than one '#' separator.
     MultipleSep,
 }
 
 impl AddressParseError {
-    /// Create new instance
+    /// Create new address parse error instance.
     pub fn new(kind: AddressParseErrorKind) -> Self {
         Self { kind }
     }
-    /// Gets the cause of address parsing failure.
+    /// Return the cause of the address parsing failure.
     pub fn kind(&self) -> &AddressParseErrorKind {
         &self.kind
     }
 }
+
 impl Display for AddressParseError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match &self.kind {
@@ -143,19 +153,43 @@ impl Display for AddressParseError {
         }
     }
 }
+
 impl crate::compat::error::Error for AddressParseError {}
+
 impl Address {
-    /// Create a new address from separate type and data parts
-    pub fn new<S: Into<String>>(tt: u8, inner: S) -> Self {
+    /// Creates a new address from separate transport type and data parts.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// # use ockam_core::Address;
+    /// # pub const TCP: u8 = 1;
+    /// // create a new remote worker address from a transport type and data
+    /// let tcp_worker: Address = Address::new(TCP, "carol");
+    /// ```
+    pub fn new<S: Into<String>>(transport: u8, data: S) -> Self {
         Self {
-            tt,
-            inner: inner.into().as_bytes().to_vec(),
+            tt: transport,
+            inner: data.into().as_bytes().to_vec(),
         }
     }
 
-    /// Parse an address from a string
+    /// Parses an address from a string.
     ///
-    /// See type documentation for more detail
+    /// # Panics
+    ///
+    /// This function will panic if passed an invalid address string.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// # use ockam_core::Address;
+    /// // parse a local worker address
+    /// let local_worker: Address = Address::from_string("alice");
+    ///
+    /// // parse a remote worker address reachable over tcp transport
+    /// let tcp_worker: Address = Address::from_string("1#carol");
+    /// ```
     pub fn from_string<S: Into<String>>(s: S) -> Self {
         match s.into().parse::<Address>() {
             Ok(a) => a,
@@ -164,16 +198,29 @@ impl Address {
             }
         }
     }
-    /// Generate a random address with a specific type
-    pub fn random(tt: u8) -> Self {
-        Self { tt, ..random() }
+
+    /// Generate a random address with the given transport type.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// # use ockam_core::Address;
+    /// // generate a random local address
+    /// let local_worker: Address = Address::random(0);
+    /// ```
+    pub fn random(transport: u8) -> Self {
+        Self {
+            tt: transport,
+            ..random()
+        }
     }
 }
+
 impl core::str::FromStr for Address {
     type Err = AddressParseError;
-    /// Parse an address from a string
+    /// Parse an address from a string.
     ///
-    /// See type documentation for more detail
+    /// See type documentation for more detail.
     fn from_str(s: &str) -> Result<Address, Self::Err> {
         let buf: String = s.into();
         let mut vec: Vec<_> = buf.split('#').collect();
@@ -203,6 +250,7 @@ impl core::str::FromStr for Address {
         }
     }
 }
+
 impl Display for Address {
     fn fmt<'a>(&'a self, f: &mut fmt::Formatter) -> fmt::Result {
         let inner: &'a str = from_utf8(self.inner.as_slice()).unwrap_or("Invalid UTF-8");
@@ -237,53 +285,56 @@ impl<'a> From<&'a str> for Address {
 }
 
 impl From<Vec<u8>> for Address {
-    fn from(inner: Vec<u8>) -> Self {
-        Self { tt: 0, inner }
+    fn from(data: Vec<u8>) -> Self {
+        Self { tt: 0, inner: data }
     }
 }
 
 impl From<(u8, Vec<u8>)> for Address {
-    fn from((tt, inner): (u8, Vec<u8>)) -> Self {
-        Self { tt, inner }
+    fn from((transport, data): (u8, Vec<u8>)) -> Self {
+        Self {
+            tt: transport,
+            inner: data,
+        }
     }
 }
 
 impl<'a> From<(u8, &'a str)> for Address {
-    fn from((tt, inner): (u8, &'a str)) -> Self {
+    fn from((transport, data): (u8, &'a str)) -> Self {
         Self {
-            tt,
-            inner: inner.as_bytes().to_vec(),
+            tt: transport,
+            inner: data.as_bytes().to_vec(),
         }
     }
 }
 
 impl From<(u8, String)> for Address {
-    fn from((tt, inner): (u8, String)) -> Self {
-        Self::from((tt, inner.as_str()))
+    fn from((transport, data): (u8, String)) -> Self {
+        Self::from((transport, data.as_str()))
     }
 }
 
 impl<'a> From<&'a [u8]> for Address {
-    fn from(inner: &'a [u8]) -> Self {
+    fn from(data: &'a [u8]) -> Self {
         Self {
             tt: 0,
-            inner: inner.to_vec(),
+            inner: data.to_vec(),
         }
     }
 }
 
 impl<'a> From<&'a [&u8]> for Address {
-    fn from(inner: &'a [&u8]) -> Self {
+    fn from(data: &'a [&u8]) -> Self {
         Self {
             tt: 0,
-            inner: inner.iter().map(|x| **x).collect(),
+            inner: data.iter().map(|x| **x).collect(),
         }
     }
 }
 
 impl From<Address> for String {
-    fn from(addr: Address) -> Self {
-        addr.to_string()
+    fn from(address: Address) -> Self {
+        address.to_string()
     }
 }
 
